==================================
salt.returners.mongo_future_return
==================================

.. automodule:: salt.returners.mongo_future_return
    :members:
    :exclude-members: save_minions
